# Screenshots

## persons found by keyword search

![keyword search](screenshots/keyword-search.jpg "persons found by keyword search")

## list of persons stored in address book

![person list](screenshots/person-list.jpg "list of persons stored in address book")

## customization abilities for list of persons

![customization of person list](screenshots/custom-person-list.png "customization abilities for list of persons")

## customization abilities for a postal address

![customization of addresses](screenshots/custom-address.png "customization abilities for a postal address")

## edit form for an address book user

![edit form](screenshots/edit-form.png "edit form for an address book user")

## calendar of icemac.ab.calendar

![calendar](screenshots/calendar.png "calendar of icemac.ab.calendar")
